@@ -24,4 +24,6 @@ typedef struct anon_client_auth_info_st anon_client_auth_info_st;
 typedef anon_client_auth_info_st anon_server_auth_info_st;
 
 gnutls_dh_params_t _gnutls_anon_get_dh_params(const
-    gnutls_anon_server_credentials_t sc, gnutls_session_t session);
+					      gnutls_anon_server_credentials_t
+					      sc,
+					      gnutls_session_t session);
