@@ -35,12 +35,13 @@ static const int anon_dummy;
 
 /**
   * gnutls_anon_free_server_credentials - Used to free an allocated gnutls_anon_server_credentials_t structure
-  * @sc: is an &gnutls_anon_server_credentials_t structure.
+  * @sc: is an #gnutls_anon_server_credentials_t structure.
   *
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to free (deallocate) it.
   **/
-void gnutls_anon_free_server_credentials(gnutls_anon_server_credentials_t sc)
+void gnutls_anon_free_server_credentials(gnutls_anon_server_credentials_t
+					 sc)
 {
 
     gnutls_free(sc);
@@ -48,14 +49,14 @@ void gnutls_anon_free_server_credentials(gnutls_anon_server_credentials_t sc)
 
 /*-
   * _gnutls_anon_get_dh_params - Returns the DH parameters pointer
-  * @sc: is an &gnutls_certificate_credentials_t structure.
+  * @sc: is an #gnutls_certificate_credentials_t structure.
   *
   * This function will return the dh parameters pointer.
   *
   -*/
 gnutls_dh_params_t _gnutls_anon_get_dh_params(const
-					    gnutls_anon_server_credentials_t
-					    sc, gnutls_session_t session)
+					      gnutls_anon_server_credentials_t
+					      sc, gnutls_session_t session)
 {
     gnutls_params_st params;
     int ret;
@@ -78,13 +79,14 @@ gnutls_dh_params_t _gnutls_anon_get_dh_params(const
 
 /**
   * gnutls_anon_allocate_server_credentials - Used to allocate an gnutls_anon_server_credentials_t structure
-  * @sc: is a pointer to an &gnutls_anon_server_credentials_t structure.
+  * @sc: is a pointer to an #gnutls_anon_server_credentials_t structure.
   *
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to allocate it.
   **/
-int gnutls_anon_allocate_server_credentials(gnutls_anon_server_credentials_t
-					    * sc)
+int
+gnutls_anon_allocate_server_credentials(gnutls_anon_server_credentials_t *
+					sc)
 {
 
     *sc = gnutls_calloc(1, sizeof(anon_server_credentials_st));
@@ -95,23 +97,26 @@ int gnutls_anon_allocate_server_credentials(gnutls_anon_server_credentials_t
 
 /**
   * gnutls_anon_free_client_credentials - Used to free an allocated gnutls_anon_client_credentials_t structure
-  * @sc: is an &gnutls_anon_client_credentials_t structure.
+  * @sc: is an #gnutls_anon_client_credentials_t structure.
   *
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to free (deallocate) it.
   **/
-void gnutls_anon_free_client_credentials(gnutls_anon_client_credentials_t sc)
+void gnutls_anon_free_client_credentials(gnutls_anon_client_credentials_t
+					 sc)
 {
 }
 
 /**
  * gnutls_anon_allocate_client_credentials - Used to allocate a credentials structure
- * @sc: is a pointer to an &gnutls_anon_client_credentials_t structure.
+ * @sc: is a pointer to an #gnutls_anon_client_credentials_t structure.
  *
  * This structure is complex enough to manipulate directly thus
  * this helper function is provided in order to allocate it.
  **/
-int gnutls_anon_allocate_client_credentials(gnutls_anon_client_credentials_t * sc)
+int
+gnutls_anon_allocate_client_credentials(gnutls_anon_client_credentials_t *
+					sc)
 {
     /* anon_dummy is only there for *sc not to be null.
      * it is not used at all;
