@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Free Software Foundation
+ *  Copyright (C) 2004, 2005 Free Software Foundation
  *  Copyright (C) 2002,2003 Nikos Mavroyanopoulos
  *
  *  This file is part of GNUTLS.
@@ -1278,10 +1278,10 @@ int gnutls_certificate_set_x509_trust_mem(gnutls_certificate_credentials_t
     int ret, ret2;
 
     if (type == GNUTLS_X509_FMT_DER)
-	return parse_der_ca_mem(&res->x509_ca_list, &res->x509_ncas,
+	ret = parse_der_ca_mem(&res->x509_ca_list, &res->x509_ncas,
 				ca->data, ca->size);
     else
-	return parse_pem_ca_mem(&res->x509_ca_list, &res->x509_ncas,
+	ret = parse_pem_ca_mem(&res->x509_ca_list, &res->x509_ncas,
 				ca->data, ca->size);
 
     if ((ret2 = generate_rdn_seq(res)) < 0)
@@ -1313,7 +1313,7 @@ int gnutls_certificate_set_x509_trust(gnutls_certificate_credentials_t res,
 				      gnutls_x509_crt_t * ca_list,
 				      int ca_list_size)
 {
-    int ret, i, j, ret2;
+    int ret, i, ret2;
 
     res->x509_ca_list = gnutls_realloc_fast(res->x509_ca_list,
 					    (ca_list_size +
