@@ -1,6 +1,7 @@
 #include <libtasn1.h>
 
-int _gnutls_x509_cert_verify_peers(gnutls_session_t session);
+int _gnutls_x509_cert_verify_peers(gnutls_session_t session,
+				   unsigned int *status);
 
 #define PEM_CERT_SEP2 "-----BEGIN X509 CERTIFICATE"
 #define PEM_CERT_SEP "-----BEGIN CERTIFICATE"
@@ -20,6 +21,7 @@ int _gnutls_x509_read_dsa_pubkey(opaque * der, int dersize,
 				 mpi_t * params);
 
 int _gnutls_x509_raw_privkey_to_gkey(gnutls_privkey * privkey,
-     const gnutls_datum_t * raw_key, gnutls_x509_crt_fmt_t type);
+				     const gnutls_datum_t * raw_key,
+				     gnutls_x509_crt_fmt_t type);
 int _gnutls_x509_privkey_to_gkey(gnutls_privkey * privkey,
 				 gnutls_x509_privkey_t);
