@@ -1,6 +1,6 @@
 /*
+ *  Copyright (C) 2004, 2005  Free Software Foundation
  *  Copyright (C) 2003 Nikos Mavroyanopoulos
- *  Copyright (C) 2004 Free Software Foundation
  *
  *  This file is part of GNUTLS.
  *
@@ -289,7 +289,7 @@ int _gnutls_x509_parse_dn(ASN1_TYPE asn1_struct,
 	memcpy(buf, out_str.data, out_str.length);
 	buf[out_str.length] = 0;
     }
-    *sizeof_buf = out_str.length;
+    *sizeof_buf = out_str.length + 1;
 
     result = 0;
 
@@ -422,6 +422,8 @@ int _gnutls_x509_parse_dn_oid(ASN1_TYPE asn1_struct,
 
 		if (result != ASN1_SUCCESS) {
 		    gnutls_assert();
+		    if (result==ASN1_MEM_ERROR)
+		        *sizeof_buf = len;
 		    result = _gnutls_asn2err(result);
 		    goto cleanup;
 		}
@@ -429,7 +431,8 @@ int _gnutls_x509_parse_dn_oid(ASN1_TYPE asn1_struct,
 		if (raw_flag != 0) {
 		    if ((uint) len > *sizeof_buf) {
 			*sizeof_buf = len;
-			return GNUTLS_E_SHORT_MEMORY_BUFFER;
+			result = GNUTLS_E_SHORT_MEMORY_BUFFER;
+			goto cleanup;
 		    }
 		    *sizeof_buf = len;
 
