@@ -945,6 +945,19 @@ void certificate_info(void)
 
 }
 
+static void print_hex_datum( gnutls_datum* dat)
+{
+unsigned int j;
+#define SPACE "\t"
+        fprintf(outfile,"\n"SPACE);
+	for (j = 0; j < dat->size; j++) {
+	    fprintf(outfile, "%.2x:", (unsigned char) dat->data[j]);
+	    if ((j+1)%15==0) fprintf(outfile,"\n"SPACE);
+	}
+	fprintf(outfile, "\n");
+}
+
+
 static void print_certificate_info(gnutls_x509_crt crt, FILE * out,
 				   unsigned int all)
 {
@@ -1032,6 +1045,40 @@ static void print_certificate_info(gnutls_x509_crt crt, FILE * out,
 	fprintf(out, " (%u bits)", bits);
     fprintf(out, "\n");
 
+    /* Print the raw public keys    
+     */
+    if (all) {
+    if (ret==GNUTLS_PK_RSA) {
+    	gnutls_datum m,e;
+    	
+    	ret = gnutls_x509_crt_get_pk_rsa_raw( crt, &m,&e);
+    	if (ret < 0) {
+    	    fprintf(stderr, "Error in key RSA data export: %s\n", gnutls_strerror(ret));
+    	}
+        
+        fprintf(outfile, "modulus:");
+        print_hex_datum( &m);
+        fprintf(outfile, "public exponent:");
+        print_hex_datum( &e);
+
+    } else if (ret==GNUTLS_PK_DSA) {
+        gnutls_datum p,q,g,y;
+    
+    	ret = gnutls_x509_crt_get_pk_dsa_raw( crt, &p,&q,&g,&y);
+    	if (ret < 0) {
+    	    fprintf(stderr, "Error in key DSA data export: %s\n", gnutls_strerror(ret));
+    	}
+
+        fprintf(outfile, "public key:");
+        print_hex_datum( &y);
+        fprintf(outfile, "p:");
+        print_hex_datum( &p);
+        fprintf(outfile, "q:");
+        print_hex_datum( &q);
+        fprintf(outfile, "g:");
+        print_hex_datum( &g);
+    }
+    }
 
     if (version >= 3)
 	fprintf(out, "\nX.509 Extensions:\n");
@@ -1400,6 +1447,7 @@ void crl_info()
 
 }
 
+
 void privkey_info(void)
 {
     gnutls_x509_privkey key;
@@ -1446,6 +1494,50 @@ void privkey_info(void)
 	cprint = UNKNOWN;
     fprintf(outfile, "%s\n", cprint);
 
+    /* Print the raw public and private keys    
+     */
+    if (ret==GNUTLS_PK_RSA) {
+    	gnutls_datum m,e,d,p,q,u;
+    	
+    	ret = gnutls_x509_privkey_export_rsa_raw( key, &m,&e,&d,&p,&q,&u);
+    	if (ret < 0) {
+    	    fprintf(stderr, "Error in key RSA data export: %s\n", gnutls_strerror(ret));
+    	}
+        
+        fprintf(outfile, "modulus:");
+        print_hex_datum( &m);
+        fprintf(outfile, "public exponent:");
+        print_hex_datum( &e);
+        fprintf(outfile, "private exponent:");
+        print_hex_datum( &d);
+        fprintf(outfile, "prime1:");
+        print_hex_datum( &p);
+        fprintf(outfile, "prime2:");
+        print_hex_datum( &q);
+        fprintf(outfile, "coefficient:");
+        print_hex_datum( &u);
+
+    } else if (ret==GNUTLS_PK_DSA) {
+        gnutls_datum p,q,g,y,x;
+    
+    	ret = gnutls_x509_privkey_export_dsa_raw( key, &p,&q,&g,&y,&x);
+    	if (ret < 0) {
+    	    fprintf(stderr, "Error in key DSA data export: %s\n", gnutls_strerror(ret));
+    	}
+
+        fprintf(outfile, "private key:");
+        print_hex_datum( &x);
+        fprintf(outfile, "public key:");
+        print_hex_datum( &y);
+        fprintf(outfile, "p:");
+        print_hex_datum( &p);
+        fprintf(outfile, "q:");
+        print_hex_datum( &q);
+        fprintf(outfile, "g:");
+        print_hex_datum( &g);
+    }
+
+    fprintf(outfile, "\n");
 
     size = sizeof(buffer);
     if ((ret = gnutls_x509_privkey_get_key_id(key, 0, buffer, &size)) < 0) {
@@ -1845,7 +1937,6 @@ int _verify_x509_mem(const void *cert, int cert_size)
     int siz, i;
     const char *ptr;
     int ret;
-    unsigned int output;
     char name[256];
     char issuer_name[256];
     size_t name_size;
@@ -2071,7 +2162,7 @@ int _verify_x509_mem(const void *cert, int cert_size)
 	exit(1);
     }
 
-    return output;
+    return 0;
 }
 
 static void print_verification_res(gnutls_x509_crt crt,
@@ -2251,7 +2342,7 @@ void generate_pkcs12(void)
 
     fprintf(stderr, "Generating a PKCS #12 structure...\n");
 
-    key = load_private_key(1);
+    key = load_private_key(0);
     crt = load_cert(0);
 
     name = get_pkcs12_key_name();
@@ -2267,16 +2358,6 @@ void generate_pkcs12(void)
 	exit(1);
     }
 
-    size = sizeof(_key_id);
-    result = gnutls_x509_privkey_get_key_id(key, 0, _key_id, &size);
-    if (result < 0) {
-	fprintf(stderr, "key_id: %s\n", gnutls_strerror(result));
-	exit(1);
-    }
-
-    key_id.data = _key_id;
-    key_id.size = size;
-
     if (crt) {			/* add the certificate only if it was specified.
 				 */
 	result = gnutls_pkcs12_bag_set_crt(bag, crt);
@@ -2289,11 +2370,20 @@ void generate_pkcs12(void)
 
 	result = gnutls_pkcs12_bag_set_friendly_name(bag, index, name);
 	if (result < 0) {
-	    fprintf(stderr, "bag_set_key_id: %s\n",
+	    fprintf(stderr, "bag_set_friendly_name: %s\n",
 		    gnutls_strerror(result));
 	    exit(1);
 	}
 
+	size = sizeof(_key_id);
+	result = gnutls_x509_crt_get_key_id(crt, 0, _key_id, &size);
+	if (result < 0) {
+	    fprintf(stderr, "key_id: %s\n", gnutls_strerror(result));
+	    exit(1);
+	}
+
+	key_id.data = _key_id;
+	key_id.size = size;
 
 	result = gnutls_pkcs12_bag_set_key_id(bag, index, &key_id);
 	if (result < 0) {
@@ -2314,50 +2404,65 @@ void generate_pkcs12(void)
 	}
     }
 
-    /* Key BAG */
+    if (key) {			/* add the key only if it was specified.
+				 */
+	result = gnutls_pkcs12_bag_init(&kbag);
+	if (result < 0) {
+	    fprintf(stderr, "bag_init: %s\n", gnutls_strerror(result));
+	    exit(1);
+	}
 
-    result = gnutls_pkcs12_bag_init(&kbag);
-    if (result < 0) {
-	fprintf(stderr, "bag_init: %s\n", gnutls_strerror(result));
-	exit(1);
-    }
+	if (info.export)
+	    flags = GNUTLS_PKCS_USE_PKCS12_RC2_40;
+	else
+	    flags = GNUTLS_PKCS_USE_PKCS12_3DES;
 
-    if (info.export)
-	flags = GNUTLS_PKCS_USE_PKCS12_RC2_40;
-    else
-	flags = GNUTLS_PKCS_USE_PKCS12_3DES;
+	size = sizeof(buffer);
+	result =
+	    gnutls_x509_privkey_export_pkcs8(key, GNUTLS_X509_FMT_DER,
+					     password, flags, buffer,
+					     &size);
+	if (result < 0) {
+	    fprintf(stderr, "key_export: %s\n", gnutls_strerror(result));
+	    exit(1);
+	}
 
-    size = sizeof(buffer);
-    result =
-	gnutls_x509_privkey_export_pkcs8(key, GNUTLS_X509_FMT_DER,
-					 password, flags, buffer, &size);
-    if (result < 0) {
-	fprintf(stderr, "key_export: %s\n", gnutls_strerror(result));
-	exit(1);
-    }
+	data.data = buffer;
+	data.size = size;
+	result =
+	    gnutls_pkcs12_bag_set_data(kbag,
+				       GNUTLS_BAG_PKCS8_ENCRYPTED_KEY,
+				       &data);
+	if (result < 0) {
+	    fprintf(stderr, "bag_set_data: %s\n", gnutls_strerror(result));
+	    exit(1);
+	}
 
-    data.data = buffer;
-    data.size = size;
-    result =
-	gnutls_pkcs12_bag_set_data(kbag, GNUTLS_BAG_PKCS8_ENCRYPTED_KEY,
-				   &data);
-    if (result < 0) {
-	fprintf(stderr, "bag_set_data: %s\n", gnutls_strerror(result));
-	exit(1);
-    }
+	index = result;
 
-    index = result;
+	result = gnutls_pkcs12_bag_set_friendly_name(kbag, index, name);
+	if (result < 0) {
+	    fprintf(stderr, "bag_set_friendly_name: %s\n",
+		    gnutls_strerror(result));
+	    exit(1);
+	}
 
-    result = gnutls_pkcs12_bag_set_friendly_name(kbag, index, name);
-    if (result < 0) {
-	fprintf(stderr, "bag_set_key_id: %s\n", gnutls_strerror(result));
-	exit(1);
-    }
+	size = sizeof(_key_id);
+	result = gnutls_x509_privkey_get_key_id(key, 0, _key_id, &size);
+	if (result < 0) {
+	    fprintf(stderr, "key_id: %s\n", gnutls_strerror(result));
+	    exit(1);
+	}
 
-    result = gnutls_pkcs12_bag_set_key_id(kbag, result, &key_id);
-    if (result < 0) {
-	fprintf(stderr, "bag_set_key_id: %s\n", gnutls_strerror(result));
-	exit(1);
+	key_id.data = _key_id;
+	key_id.size = size;
+
+	result = gnutls_pkcs12_bag_set_key_id(kbag, result, &key_id);
+	if (result < 0) {
+	    fprintf(stderr, "bag_set_key_id: %s\n",
+		    gnutls_strerror(result));
+	    exit(1);
+	}
     }
 
     /* write the PKCS #12 structure.
@@ -2376,10 +2481,12 @@ void generate_pkcs12(void)
 	}
     }
 
-    result = gnutls_pkcs12_set_bag(pkcs12, kbag);
-    if (result < 0) {
-	fprintf(stderr, "set_bag: %s\n", gnutls_strerror(result));
-	exit(1);
+    if (key) {
+	result = gnutls_pkcs12_set_bag(pkcs12, kbag);
+	if (result < 0) {
+	    fprintf(stderr, "set_bag: %s\n", gnutls_strerror(result));
+	    exit(1);
+	}
     }
 
     result = gnutls_pkcs12_generate_mac(pkcs12, password);
