@@ -1,6 +1,6 @@
 /*
+ * Copyright (C) 2004, 2005 Free Software Foundation
  * Copyright (C) 2000,2001,2002,2003 Nikos Mavroyanopoulos
- * Copyright (C) 2004 Free Software Foundation
  *
  * This file is part of GNUTLS.
  *
@@ -266,7 +266,6 @@ static int cert_callback(gnutls_session session,
     char issuer_dn[256];
     int i, ret;
     size_t len;
-    gnutls_certificate_type type;
 
     if (verbose) {
 
@@ -293,11 +292,12 @@ static int cert_callback(gnutls_session session,
      * The certificate must be of any of the "sign algorithms"
      * supported by the server.
      */
-    st->type = type;
+
+    st->type = gnutls_certificate_type_get(session);
+
     st->ncerts = 0;
 
-    type = gnutls_certificate_type_get(session);
-    if (type == GNUTLS_CRT_X509) {
+    if (st->type == GNUTLS_CRT_X509) {
 	if (x509_crt != NULL && x509_key != NULL) {
 	    st->ncerts = 1;
 
@@ -308,7 +308,7 @@ static int cert_callback(gnutls_session session,
 
 	    return 0;
 	}
-    } else if (type == GNUTLS_CRT_OPENPGP) {
+    } else if (st->type == GNUTLS_CRT_OPENPGP) {
 	if (pgp_key != NULL && pgp_crt != NULL) {
 	    st->ncerts = 1;
 
